@@ -484,6 +484,55 @@ START_TEST(test_rhonabwy_flood_ok)
 }
 END_TEST
 
+START_TEST(test_rhonabwy_check_key_length)
+{
+  jwe_t * jwe_enc_1, * jwe_enc_2, * jwe_dec_1, * jwe_dec_2;
+  jwk_t * jwk_1, * jwk_2;
+  char * token_1, * token_2;
+  
+  ck_assert_int_eq(r_jwk_init(&jwk_1), RHN_OK);
+  ck_assert_int_eq(r_jwk_init(&jwk_2), RHN_OK);
+  ck_assert_int_eq(r_jwe_init(&jwe_enc_1), RHN_OK);
+  ck_assert_int_eq(r_jwe_init(&jwe_enc_2), RHN_OK);
+
+  ck_assert_int_eq(r_jwk_import_from_json_str(jwk_1, jwk_key_128_1), RHN_OK);
+  ck_assert_int_eq(r_jwk_import_from_json_str(jwk_2, jwk_key_256_1), RHN_OK);
+
+  ck_assert_int_eq(r_jwe_set_payload(jwe_enc_1, (const unsigned char *)PAYLOAD, o_strlen(PAYLOAD)), RHN_OK);
+  ck_assert_int_eq(r_jwe_set_alg(jwe_enc_1, R_JWA_ALG_A128KW), RHN_OK);
+  ck_assert_int_eq(r_jwe_set_enc(jwe_enc_1, R_JWA_ENC_A128CBC), RHN_OK);
+  ck_assert_ptr_ne((token_1 = r_jwe_serialize(jwe_enc_1, jwk_1, 0)), NULL);
+
+  ck_assert_int_eq(r_jwe_set_payload(jwe_enc_2, (const unsigned char *)PAYLOAD, o_strlen(PAYLOAD)), RHN_OK);
+  ck_assert_int_eq(r_jwe_set_alg(jwe_enc_2, R_JWA_ALG_A256KW), RHN_OK);
+  ck_assert_int_eq(r_jwe_set_enc(jwe_enc_2, R_JWA_ENC_A256CBC), RHN_OK);
+  ck_assert_ptr_ne((token_2 = r_jwe_serialize(jwe_enc_2, jwk_2, 0)), NULL);
+  
+  ck_assert_ptr_ne((jwe_dec_1 = r_jwe_quick_parse(token_1, R_PARSE_NONE, 0)), NULL);
+  ck_assert_int_eq(r_jwe_decrypt(jwe_dec_1, jwk_1, 0), RHN_OK);
+  r_jwe_free(jwe_dec_1);
+
+  ck_assert_ptr_ne((jwe_dec_2 = r_jwe_quick_parse(token_2, R_PARSE_NONE, 0)), NULL);
+  ck_assert_int_eq(r_jwe_decrypt(jwe_dec_2, jwk_2, 0), RHN_OK);
+  r_jwe_free(jwe_dec_2);
+  
+  ck_assert_ptr_ne((jwe_dec_1 = r_jwe_quick_parse(token_1, R_PARSE_NONE, 0)), NULL);
+  ck_assert_int_eq(r_jwe_decrypt(jwe_dec_1, jwk_2, 0), RHN_ERROR_INVALID);
+  r_jwe_free(jwe_dec_1);
+
+  ck_assert_ptr_ne((jwe_dec_2 = r_jwe_quick_parse(token_2, R_PARSE_NONE, 0)), NULL);
+  ck_assert_int_eq(r_jwe_decrypt(jwe_dec_2, jwk_1, 0), RHN_ERROR_INVALID);
+  r_jwe_free(jwe_dec_2);
+  
+  r_jwk_free(jwk_1);
+  r_jwk_free(jwk_2);
+  r_jwe_free(jwe_enc_1);
+  r_jwe_free(jwe_enc_2);
+  r_free(token_1);
+  r_free(token_2);
+}
+END_TEST
+
 START_TEST(test_rhonabwy_rfc_example)
 {
   const char jwe_a_3[] = 
@@ -536,6 +585,7 @@ static Suite *rhonabwy_suite(void)
   tcase_add_test(tc_core, test_rhonabwy_encrypt_decrypt_a192kw_ok);
   tcase_add_test(tc_core, test_rhonabwy_encrypt_decrypt_a256kw_ok);
   tcase_add_test(tc_core, test_rhonabwy_flood_ok);
+  tcase_add_test(tc_core, test_rhonabwy_check_key_length);
   tcase_add_test(tc_core, test_rhonabwy_rfc_example);
 #endif
   tcase_set_timeout(tc_core, 30);
